from django.test import TestCase
from artd_partner.models import Partner, Headquarter, Position, Coworker
from artd_location.models import Country, Region, City
from artd_partner.utils.generators import generate_random_string, generate_random_email

# Create your tests here.


class TestPartner(TestCase):
    def setUp(self):
        self.country = Country.objects.create(
            spanish_name=generate_random_string(),
            english_name=generate_random_string(),
            nom=generate_random_string(),
            iso2=generate_random_string(),
            phone_code=generate_random_string(),
        )
        self.region = Region.objects.create(
            name=generate_random_string(),
            country=self.country,
        )
        self.city = City.objects.create(
            name=generate_random_string(),
            name_in_capital_letters=generate_random_string(),
            code=generate_random_string(),
            region=self.region,
        )

        self.position = Position.objects.create(name="Gerente")
        self.partner = Partner.objects.create(
            name=generate_random_string(),
            dni=generate_random_string(),
            email=generate_random_email(),
            city=self.city,
            address=generate_random_string(),
        )
        self.headquarter = Headquarter.objects.create(
            name=generate_random_string(),
            address=generate_random_email(),
            city=self.city,
            phone=generate_random_string(),
            partner=self.partner,
        )
        self.coworker = Coworker.objects.create(
            first_name=generate_random_string(),
            last_name=generate_random_string(),
            dni=generate_random_string(),
            email=generate_random_email(),
            position=self.position,
            headquarter=self.headquarter,
        )

    def test_position(self):
        assert Position.objects.count() == 1

    def test_partner(self):
        assert Partner.objects.count() == 1

    def test_headquarter(self):
        assert Headquarter.objects.count() == 1

    def test_coworker(self):
        assert Coworker.objects.count() == 1



from django.contrib import admin
from artd_partner.models import Partner, Headquarter, Position, Coworker


@admin.register(Partner)
class PartnerAdmin(admin.ModelAdmin):
    """Admin view for Partner."""

    list_display = (
        "name",
        "partner_slug",
        "dni",
        "address",
        "city",
    )
    list_filter = (
        "city",
        "partner_slug",
    )
    search_fields = (
        "name",
        "partner_slug",
        "dni",
        "address",
        "city__name",
    )


@admin.register(Headquarter)
class HeadquarterAdmin(admin.ModelAdmin):
    """Admin view for Headquarter."""

    list_display = (
        "name",
        "address",
        "city",
        "phone",
        "partner",
    )
    list_filter = ("city", "partner")
    search_fields = (
        "name",
        "address",
        "city__name",
        "phone",
        "partner__name",
    )


@admin.register(Position)
class PositionAdmin(admin.ModelAdmin):
    """Admin view for Position."""

    list_display = ("name",)
    search_fields = ("name",)


@admin.register(Coworker)
class CoworkerAdmin(admin.ModelAdmin):
    """Admin view for Coworker."""

    list_display = (
        "first_name",
        "last_name",
        "dni",
        "phone",
        "position",
        "headquarter",
    )
    list_filter = ("position", "headquarter")
    search_fields = (
        "first_name",
        "last_name",
        "dni",
        "phone",
        "position__name",
        "headquarter__name",
    )



# Generated by Django 4.2.2 on 2023-08-29 10:56

from django.db import migrations, models


class Migration(migrations.Migration):
    dependencies = [
        ("artd_partner", "0002_headquarter_partner_slug"),
    ]

    operations = [
        migrations.RemoveField(
            model_name="headquarter",
            name="partner_slug",
        ),
        migrations.AddField(
            model_name="partner",
            name="partner_slug",
            field=models.SlugField(
                default="",
                help_text="Slug of headquarter",
                max_length=150,
                unique=True,
                verbose_name="slug",
            ),
        ),
    ]
